CON
           
' *******************************************************************************************************
' *                                                                                                     *
' *     AiChip I2C Slave Demonstration                                    AiChip_I2cSlave_Demo_003      *
' *                                                                                                     *
' *******************************************************************************************************
' *                                                                                                     *
' *     Object Name    : AiChip I2C Slave Demonstration                                                 *
' *     Version        : 003                                                                            *
' *     Updated        : 2008-04-12                                                                     *
' *                                                                                                     *
' *     Author         : AiChip Industries                                                              *
' *                                                                                                     *
' *     Copyright      : 2008, AiChip Industries                                                        *
' *                                                                                                     *
' *     Target Chip    : Parallax Propeller Chip P8X32A ( "Propeller Mk I" )                            *
' *     Compiler Used  : Parallax Propeller Tool 1.1                                                    *
' *                                                                                                     *
' *     License        : MIT License. Please see end of this file for Terms of Use.                     *
' *                                                                                                     *
' *******************************************************************************************************
' *                                                                                                     *
' *     AiChip is a trademark of AiChip Industries.                                                     *
' *                                                                                                     *
' *     If distributing a modified version of this software AiChip Industries requests the "AiChip"     *
' *     prefix be removed from the filename and internal text descriptions to avoid any confusion that  *
' *     may be caused by an impression that the modified software originates from AiChip Industries.    *
' *                                                                                                     *
' *******************************************************************************************************

' *******************************************************************************************************
' *                                                                                                     *
' *     KNOWN BUGS                                                                                      *
' *                                                                                                     *
' *     003     2008-04-12      Start two I2C Slave handlers with different Device ID's and the tests   *
' *                             will fail. There is some timing or I/O interaction going on which is a  *
' *                             sign something is wrong somewhere.                                      *
' *                                                                                                     *
' *******************************************************************************************************

' *******************************************************************************************************
' *                                                                                                     *
' *     HISTORY                                                                                         *
' *                                                                                                     *
' *     003     2008-04-12      Uses latest PASM version of I2C Slave - Working                         *
' *                                                                                                     *
' *     002     2008-04-12      PASM version of I2C Slave included - Not working yet                    *
' *                             Improved I2C Master control line handling                               *
' *                                                                                                     *
' *     001     2008-04-11      First Public Release                                                    *
' *                                                                                                     *
' *******************************************************************************************************

PRI Version

  result := String( "AiChip_I2cSlave_Demo_003" )
  
CON

  _CLKMODE      = XTAL1 + PLL16x
  _XINFREQ      = 5_000_000

  TV_PIN        = 12
  
  SDA_PIN       = 29
  SCL_PIN       = 28

OBJ

  tv            : "TV_Text"
  
  i2c_Slave     : "AiChip_I2cSlave_Slave_003"
  i2c_Master    : "AiChip_I2cSlave_Master_003"
  
PUB Demo | testNum, pc, n, repeatCount

  tv.Start( TV_PIN )

  ' Start the I2C Slave running. It uses the same I2C lines as the master does so no wiring needed.

  i2c_Slave.Start( SCL_PIN, SDA_PIN, $E0, 0, 0, 0 )

  ' Allow the I2C Slave time to start so we can be sure that starting the I2C Master doesn't cause it any
  ' problems when kicking the I2C bus into life.
  
  WaitCnt( CLKFREQ / 1000 * 100 + CNT )

  ' Initialise the I2C Master code so it knows what it's about to communicate with.
  
  i2c_Master.OpenRaw( SCL_PIN, SDA_PIN, $E0, 0, 0 )

  ' Test every possible pattern in the 256 byte virtual I2C Ram

  repeatCount := $100
      
  testNum := 0
  repeat repeatCount

    tv.Out( $01 )
    tv.Str( Version )
    tv.Out( $0D )
    tv.Str( i2c_Slave.Version )
    tv.Out( $0D )
    tv.Str( i2c_Master.Version )
    tv.Str( String( $0D,$0D,"Test : " ) )
    tv.Hex( testNum, 3 )

    pc := 0
    n  := testNum
    repeat repeatCount
      i2c_Master.WriteByte( pc++, n++ )  

    repeat 2
      pc := 0
      n  := testNum
      repeat repeatCount
        if i2c_Master.ReadByte ( pc ) <> ( n & $FF )
          tv.Str( String( $0D,$0D,"FAILED : At " ) )
          tv.Hex( pc, 4 )
          tv.Str( String( " Wrote ") )
          tv.Hex( n , 2 )
          tv.Str( String( " Read ") )
          tv.Hex( i2c_Master.ReadByte( pc ), 2 )
          repeat
        else
          pc++
          n++

    testNum++

  tv.Str( String( $0D,$0D,"PASSED ALL TESTS") )

CON

' *******************************************************************************************************
' *                                                                                                     *
' *     Terms of Use : MIT License                                                                      *
' *                                                                                                     *
' *******************************************************************************************************
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
' associated documentation files (the "Software"), to deal in the Software without restriction, including
' without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
' copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to
' the following conditions:                                                                   
'
' The above copyright notice and this permission notice shall be included in all copies or substantial
' portions of the Software.                                                                                             
'                                                                                                                  
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
' LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
' NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
' WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
' SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

CON

' *******************************************************************************************************
' *                                                                                                     *
' *     End of AiChip I2C Slave Demonstration                                                           *
' *                                                                                                     *
' *******************************************************************************************************
        